==> haskell-irc-core-2.12-65-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-irc-core.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 irc-core
version:              2.12
visibility:           public
id:                   irc-core-2.12-LHP8vMekz73LS7xxUSRefh
key:                  irc-core-2.12-LHP8vMekz73LS7xxUSRefh
license:              ISC
copyright:            2016 Eric Mertens
maintainer:           emertens@gmail.com
author:               Eric Mertens
homepage:             https://github.com/glguy/irc-core
synopsis:             IRC core library for glirc
description:
    IRC core library for glirc
    .
    The glirc client has been split off into <https://hackage.haskell.org/package/glirc>

category:             Network
abi:                  3bcb53c1acc75365defe0b59e116da37
exposed:              True
exposed-modules:
    Irc.Codes Irc.Commands Irc.Identifier Irc.Message Irc.Modes
    Irc.RateLimit Irc.RawIrcMsg Irc.UserInfo

hidden-modules:       View
import-dirs:          /usr/lib/ghc-9.4.8/site-local/irc-core-2.12
library-dirs:         /usr/lib/ghc-9.4.8/site-local/irc-core-2.12
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/irc-core-2.12
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-irc-core
hs-libraries:         HSirc-core-2.12-LHP8vMekz73LS7xxUSRefh
depends:
    attoparsec-0.14.4-G1kY79wp4BCwb0EQHIFQA base-4.17.2.1
    base64-bytestring-1.2.1.0-9TOa4ZiPzZCEZmYgmgxjAh
    bytestring-0.11.5.3 hashable-1.4.4.0-L4Cy5OzOiFo7EDda82f1f2
    primitive-0.9.1.0-D2Xl5aBZhziHIyHGKnXxcR text-2.0.2 time-1.12.2
    vector-0.13.2.0-ESntcdl2teUG0zU6GNugJH

haddock-interfaces:   /usr/share/doc/haskell-irc-core/html/irc-core.haddock
haddock-html:         /usr/share/doc/haskell-irc-core/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-irc-core-2.12-66-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-irc-core.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 irc-core
version:              2.12
visibility:           public
id:                   irc-core-2.12-8u1lGx28Qni3DygaXmWszg
key:                  irc-core-2.12-8u1lGx28Qni3DygaXmWszg
license:              ISC
copyright:            2016 Eric Mertens
maintainer:           emertens@gmail.com
author:               Eric Mertens
homepage:             https://github.com/glguy/irc-core
synopsis:             IRC core library for glirc
description:
    IRC core library for glirc
    .
    The glirc client has been split off into <https://hackage.haskell.org/package/glirc>

category:             Network
abi:                  2ae4ea265e3754b2d9fc27328ff66d23
exposed:              True
exposed-modules:
    Irc.Codes Irc.Commands Irc.Identifier Irc.Message Irc.Modes
    Irc.RateLimit Irc.RawIrcMsg Irc.UserInfo

hidden-modules:       View
import-dirs:          /usr/lib/ghc-9.4.8/site-local/irc-core-2.12
library-dirs:         /usr/lib/ghc-9.4.8/site-local/irc-core-2.12
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/irc-core-2.12
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-irc-core
hs-libraries:         HSirc-core-2.12-8u1lGx28Qni3DygaXmWszg
depends:
    attoparsec-0.14.4-2LtDsLmLe3yKhxR8c5Iii0 base-4.17.2.1
    base64-bytestring-1.2.1.0-7CU13IWnWdcDMU9nDc25iT
    bytestring-0.11.5.3 hashable-1.4.4.0-6tleuNdu8X41J3b2E1oOOY
    primitive-0.9.1.0-LKIwDdhUWCeBBmo7dhK3va text-2.0.2 time-1.12.2
    vector-0.13.2.0-ByKMfTK8tTR39fPNQcIOcc

haddock-interfaces:   /usr/share/doc/haskell-irc-core/html/irc-core.haddock
haddock-html:         /usr/share/doc/haskell-irc-core/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
